@@ -2,7 +2,7 @@
 package App::PAIA::Command::request;
 use base 'App::PAIA::Command';
 use v5.14;
-our $VERSION = '0.10'; #VERSION
+our $VERSION = '0.11'; #VERSION
 
 use App::PAIA::JSON;
 
@@ -20,7 +20,7 @@ sub execute {
         unless @docs;
 
     my $response = $self->core_request( 'POST', 'request', { doc => \@docs } );
-    say encode_json($response);
+    print encode_json($response);
 }
 
 1;
@@ -36,7 +36,7 @@ App::PAIA::Command::request - request one or more items for reservation or deliv
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHOR
 
